@@ -220,3 +220,40 @@ align_text <- function(x, n) {
   return(gsub("\n", paste0("\n", paste(rep(" ", n), collapse = "")), x,
               fixed = TRUE))
 }
+
+#' Default solver name
+#'
+#' This function returns the name of the default solver. If no sovlers are
+#' detected on the system, then a \code{NULL} object is retured.
+#'
+#' @details This function tests if any of the following packages are installed:
+#'   \code{Rsymphony}, \code{lpsymphony}, \code{gurobi}.
+#'
+#' @return \code{character} indicating the name of the default solver.
+#'
+#' @noRd
+default_solver_name <- function() {
+  if (requireNamespace("gurobi", quietly = TRUE)) {
+    return("gurobi")
+  } else if (requireNamespace("Rsymphony", quietly = TRUE)) {
+    return("Rsymphony")
+  } else if (requireNamespace("lpsymphony", quietly = TRUE)) {
+    return("lpsymphony")
+  } else {
+    return(NULL)
+  }
+}
+
+#' Any solvers installed?
+#'
+#' Test if any solvers are installed.
+#'
+#' @details This function tests if any of the following packages are installed:
+#'   \code{Rsymphony}, \code{lpsymphony}, \code{gurobi}.
+#'
+#' @return \code{logical} value indicating if any solvers are installed.
+#'
+#' @noRd
+any_solvers_installed <- function() {
+  !is.null(default_solver_name())
+}
