@@ -32,6 +32,8 @@ test_that("compile (compressed formulation)", {
 
 test_that("solution (compressed formulation)", {
   skip_on_cran()
+  skip_if_not(default_solver_name() != "lpsymphony")
+  skip_if_not(any_solvers_installed())
   # create data
   budget <- 4.23
   cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
@@ -44,7 +46,7 @@ test_that("solution (compressed formulation)", {
         add_max_utility_objective(budget = budget) %>%
         add_locked_in_constraints(locked_in) %>%
         add_locked_out_constraints(locked_out) %>%
-        add_default_solver(time_limit = 5)
+        add_default_solver(gap = 0)
   # solve problem
   s <- solve(p)
   # test that solution is correct
@@ -99,6 +101,8 @@ test_that("compile (expanded formulation)", {
 
 test_that("solution (expanded formulation)", {
   skip_on_cran()
+  skip_if_not(default_solver_name() != "lpsymphony")
+  skip_if_not(any_solvers_installed())
   # create data
   budget <- 4.23
   cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
@@ -111,7 +115,7 @@ test_that("solution (expanded formulation)", {
         add_max_utility_objective(budget = budget) %>%
         add_locked_in_constraints(locked_in) %>%
         add_locked_out_constraints(locked_out) %>%
-        add_default_solver(time_limit = 5)
+        add_default_solver(gap = 0)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test that solution is correct
